@@ -1,3 +1,5 @@
+from pytest import mark
+
 from . import Indenter
 
 
@@ -55,3 +57,37 @@ def test_multiple_indenters():
                 with inda:
                     assert str(inda) == "**"
                     assert str(indb) == "$$"
+
+
+@mark.xfail(reason="str + ind calls str.__add__, which afaik we can't influence")
+def test_add_ind_to_str():
+    ind = Indenter()
+    assert "some text" + ind == "some text"
+
+    with ind:
+        assert "some text" + ind == "  some text"
+
+
+def test_add_str_to_ind():
+    ind = Indenter()
+    assert ind + "some text" == "some text"
+
+    with ind:
+        assert ind + "some text" == "  some text"
+
+
+@mark.xfail(reason="str += ind calls str.__add__, which afaik we can't influence")
+def test_iadd_ind_to_str():
+    ind = Indenter()
+    with ind:
+        s = "some text"
+        s += ind
+        assert s == "some text  "
+
+
+def test_iadd_str_to_ind():
+    ind = Indenter()
+    with ind:
+        s = "some text"
+        ind += s
+        assert ind == "  some text"
